==> blancoXliff-0.0.2-src.zip: blancoXliff/blanco/main/blanco/xliff/valueobject/BlancoXliff.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.valueobject;

import java.util.List;

/**
 * OASIS XLIFF 킷o[IuWFNgB
 */
public class BlancoXliff {
    /**
     * tB[h [version]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["1.0"]<br>
     * o[WB
     */
    private String fVersion = "1.0";

    /**
     * tB[h [source-language]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["en-US"]<br>
     * \[XB
     */
    private String fSourceLanguage = "en-US";

    /**
     * tB[h [transUnitList]
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * |󃆃jbg̃XgB
     */
    private List fTransUnitList = new java.util.ArrayList();

    /**
     * tB[h [version]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o[WB
     *
     * @param argVersion tB[h[version]Ɋi[l
     */
    public void setVersion(final String argVersion) {
        fVersion = argVersion;
    }

    /**
     * tB[h[version]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["1.0"]<br>
     * o[WB
     *
     * @return tB[h[version]Ɋi[Ăl
     */
    public String getVersion() {
        return fVersion;
    }

    /**
     * tB[h [source-language]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[XB
     *
     * @param argSourceLanguage tB[h[source-language]Ɋi[l
     */
    public void setSourceLanguage(final String argSourceLanguage) {
        fSourceLanguage = argSourceLanguage;
    }

    /**
     * tB[h[source-language]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["en-US"]<br>
     * \[XB
     *
     * @return tB[h[source-language]Ɋi[Ăl
     */
    public String getSourceLanguage() {
        return fSourceLanguage;
    }

    /**
     * tB[h [transUnitList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * |󃆃jbg̃XgB
     *
     * @param argTransUnitList tB[h[transUnitList]Ɋi[l
     */
    public void setTransUnitList(final List argTransUnitList) {
        fTransUnitList = argTransUnitList;
    }

    /**
     * tB[h[transUnitList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * |󃆃jbg̃XgB
     *
     * @return tB[h[transUnitList]Ɋi[Ăl
     */
    public List getTransUnitList() {
        return fTransUnitList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.valueobject.BlancoXliff[");
        buf.append("version=" + fVersion);
        buf.append(",source-language=" + fSourceLanguage);
        buf.append(",transUnitList=" + fTransUnitList);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoXliff-0.0.5-src.zip: blancoXliff/blanco/main/blanco/xliff/valueobject/BlancoXliff.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.valueobject;

import java.util.List;

/**
 * OASIS XLIFF 킷o[IuWFNgB
 */
public class BlancoXliff {
    /**
     * tB[h [version]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["1.2"]<br>
     * o[WB
     */
    private String fVersion = "1.2";

    /**
     * tB[h [source-language]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["en-US"]<br>
     * \[XB
     */
    private String fSourceLanguage = "en-US";

    /**
     * tB[h [target-language]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["ja-JP"]<br>
     * ^[QbgB
     */
    private String fTargetLanguage = "ja-JP";

    /**
     * tB[h [transUnitList]
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * |󃆃jbg̃XgB
     */
    private List fTransUnitList = new java.util.ArrayList();

    /**
     * tB[h [toolList]
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * c[̃XgB
     */
    private List fToolList = new java.util.ArrayList();

    /**
     * tB[h [version]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o[WB
     *
     * @param argVersion tB[h[version]Ɋi[l
     */
    public void setVersion(final String argVersion) {
        fVersion = argVersion;
    }

    /**
     * tB[h[version]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["1.2"]<br>
     * o[WB
     *
     * @return tB[h[version]Ɋi[Ăl
     */
    public String getVersion() {
        return fVersion;
    }

    /**
     * tB[h [source-language]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[XB
     *
     * @param argSourceLanguage tB[h[source-language]Ɋi[l
     */
    public void setSourceLanguage(final String argSourceLanguage) {
        fSourceLanguage = argSourceLanguage;
    }

    /**
     * tB[h[source-language]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["en-US"]<br>
     * \[XB
     *
     * @return tB[h[source-language]Ɋi[Ăl
     */
    public String getSourceLanguage() {
        return fSourceLanguage;
    }

    /**
     * tB[h [target-language]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgB
     *
     * @param argTargetLanguage tB[h[target-language]Ɋi[l
     */
    public void setTargetLanguage(final String argTargetLanguage) {
        fTargetLanguage = argTargetLanguage;
    }

    /**
     * tB[h[target-language]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["ja-JP"]<br>
     * ^[QbgB
     *
     * @return tB[h[target-language]Ɋi[Ăl
     */
    public String getTargetLanguage() {
        return fTargetLanguage;
    }

    /**
     * tB[h [transUnitList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * |󃆃jbg̃XgB
     *
     * @param argTransUnitList tB[h[transUnitList]Ɋi[l
     */
    public void setTransUnitList(final List argTransUnitList) {
        fTransUnitList = argTransUnitList;
    }

    /**
     * tB[h[transUnitList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * |󃆃jbg̃XgB
     *
     * @return tB[h[transUnitList]Ɋi[Ăl
     */
    public List getTransUnitList() {
        return fTransUnitList;
    }

    /**
     * tB[h [toolList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * c[̃XgB
     *
     * @param argToolList tB[h[toolList]Ɋi[l
     */
    public void setToolList(final List argToolList) {
        fToolList = argToolList;
    }

    /**
     * tB[h[toolList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * c[̃XgB
     *
     * @return tB[h[toolList]Ɋi[Ăl
     */
    public List getToolList() {
        return fToolList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.valueobject.BlancoXliff[");
        buf.append("version=" + fVersion);
        buf.append(",source-language=" + fSourceLanguage);
        buf.append(",target-language=" + fTargetLanguage);
        buf.append(",transUnitList=" + fTransUnitList);
        buf.append(",toolList=" + fToolList);
        buf.append("]");
        return buf.toString();
    }
}
